<?php

namespace Litecms\Empdetail\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Empdetail\Models\EmpDetails;

class EmpDetailsPolicy
{

    /**
     * Determine if the given user can view the emp_details.
     *
     * @param UserPolicy $user
     * @param EmpDetails $emp_details
     *
     * @return bool
     */
    public function view(UserPolicy $user, EmpDetails $emp_details)
    {
        if ($user->canDo('empdetail.emp_details.view') && $user->isAdmin()) {
            return true;
        }

        return $emp_details->user_id == user_id() && $emp_details->user_type == user_type();
    }

    /**
     * Determine if the given user can create a emp_details.
     *
     * @param UserPolicy $user
     * @param EmpDetails $emp_details
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('empdetail.emp_details.create');
    }

    /**
     * Determine if the given user can update the given emp_details.
     *
     * @param UserPolicy $user
     * @param EmpDetails $emp_details
     *
     * @return bool
     */
    public function update(UserPolicy $user, EmpDetails $emp_details)
    {
        if ($user->canDo('empdetail.emp_details.edit') && $user->isAdmin()) {
            return true;
        }

        return $emp_details->user_id == user_id() && $emp_details->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given emp_details.
     *
     * @param UserPolicy $user
     * @param EmpDetails $emp_details
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EmpDetails $emp_details)
    {
        return $emp_details->user_id == user_id() && $emp_details->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given emp_details.
     *
     * @param UserPolicy $user
     * @param EmpDetails $emp_details
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EmpDetails $emp_details)
    {
        if ($user->canDo('empdetail.emp_details.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given emp_details.
     *
     * @param UserPolicy $user
     * @param EmpDetails $emp_details
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EmpDetails $emp_details)
    {
        if ($user->canDo('empdetail.emp_details.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
